@@ -59,6 +59,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} jakoi kanssasi tiedoston, joka ei ole enää saatavilla",
     "You shared a file which is no longer available" : "Jaoit tiedoston, joka ei ole enää saatavilla",
     "%s (guest)" : "%s (vieras)",
+    "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
     "Call with {user1} and {user2} (Duration {duration})" : "Puhelu käyttäjien {user1} ja {user2} kesken (Kesto {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
@@ -90,7 +91,6 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
     "Answer call" : "Vastaa puheluun",
     "Call back" : "Soita takaisin",
-    "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
     "Open settings" : "Avaa asetukset",
     "Conversations" : "Keskustelut",
@@ -266,6 +266,7 @@ OC.L10N.register(
     "Channel name" : "Kanavan nimi",
     "Password" : "Salasana",
     "Rocket.Chat channel" : "Rocket.Chat-kanava",
+    "Skip TLS verification" : "Ohita TLS-vahvistus",
     "API token" : "API-poletti",
     "Login" : "Kirjaudu",
     "Nickname" : "Nimimerkki",
@@ -275,7 +276,6 @@ OC.L10N.register(
     "NickServ password" : "NickServ-salasana",
     "Use TLS" : "Käytä TLS:ää",
     "Use SASL" : "Käytä SASL:ia",
-    "Skip TLS verification" : "Ohita TLS-vahvistus",
     "Client ID" : "Asiakkaan tunniste",
     "Bridge saved" : "Silta tallennettu",
     "Remove from favorites" : "Poista suosikeista",
@@ -314,6 +314,7 @@ OC.L10N.register(
     "No camera available" : "Ei kameraa saatavilla",
     "Select camera" : "Valitse kamera",
     "Reply" : "Vastaa",
+    "Go to file" : "Siirry tiedostoon",
     "Scroll to bottom" : "Vieritä alas",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
@@ -352,7 +353,6 @@ OC.L10N.register(
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Start call" : "Aloita puhelu",
     "Toggle fullscreen" : "Koko näyttö päälle/pois",
-    "Go to file" : "Siirry tiedostoon",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
     "Mute others" : "Mykistä muut",
     "Grid view" : "Ruudukkonäkymä",
@@ -395,6 +395,7 @@ OC.L10N.register(
     "iOS app" : "iOS-sovellus",
     "New in Talk 6" : "Uutta Talkin 6-versiossa",
     "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
+    "E-mail of the user" : "Käyttäjän sähköpostiosoite",
     "Error: Can not connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
     "UDP and TCP" : "UDP ja TCP",
     "UDP only" : "Vain UDP",
@@ -406,22 +407,17 @@ OC.L10N.register(
     "Disable video (v)" : "Poista video käytöstä (v)",
     "Enable video (v)" : "Ota video käyttöön (v)",
     "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
-    "Default location for attachments" : "Oletussijainti liitteille",
-    "Select default location for attachments" : "Valitse liitteiden oletussijainti",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
-    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
-    "Projects" : "Projektit",
-    "Share link" : "Jaa linkki",
-    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
-    "Fullscreen (f)" : "Koko näytön tila (f)",
-    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
-    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
-    "E-mail of the user" : "Käyttäjän sähköpostiosoite",
     "Remove" : "Poista",
     "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
     "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
     "Enabled" : "Käytössä",
     "Show matterbridge log" : "Näytä matterbridge-loki",
-    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite"
+    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
+    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
+    "Share link" : "Jaa linkki",
+    "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
+    "Fullscreen (f)" : "Koko näytön tila (f)",
+    "Error while uploading file" : "Virhe tiedostoa lähettäessä"
 },
 "nplurals=2; plural=(n != 1);");
