@@ -35,6 +35,9 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
+    "{actor} set the description" : "{actor} nustatė aprašą",
+    "You set the description" : "Jūs nustatėte aprašą",
+    "An administrator set the description" : "Administratorius nustatė aprašą",
     "{actor} removed the description" : "{actor} pašalino aprašą",
     "You removed the description" : "Jūs pašalinote aprašą",
     "An administrator removed the description" : "Administratorius pašalino aprašą",
@@ -89,6 +92,10 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
     "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
     "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
+    "{actor} deleted a message" : "{actor} ištrynė žinutę",
+    "You deleted a message" : "Jūs ištrynėte žinutę",
+    "{actor} cleared the history of the conversation" : "{actor} išvalė pokalbio istoriją",
+    "You cleared the history of the conversation" : "Jūs išvalėte pokalbio istoriją",
     "%s (guest)" : "%s (svečias)",
     "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
@@ -414,7 +421,10 @@ OC.L10N.register(
     "TURN server protocols" : "TURN serverio protokolai",
     "Test this server" : "Išbandyti šį serverį",
     "TURN servers" : "TURN serveriai",
+    "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
+    "A participant raised their hand." : "Dalyvis pakėlė ranką.",
     "Copy link" : "Kopijuoti nuorodą",
+    "Connecting …" : "Jungiamasi…",
     "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
     "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
@@ -423,12 +433,21 @@ OC.L10N.register(
     "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
+    "Lower hand (R)" : "Nuleisti ranką (R)",
+    "More actions" : "Daugiau veiksmų",
     "Settings" : "Nustatymai",
     "Dismiss" : "Atmesti",
+    "Raise hand (R)" : "Pakelti ranką (R)",
+    "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
     "No audio" : "Nėra jokio garso",
+    "Mute audio (M)" : "Nutildyti garsą (M)",
+    "Unmute audio (M)" : "Įjungti garsą (M)",
     "Mute audio" : "Nutildyti garsą",
     "Unmute audio" : "Įjungti garsą",
+    "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
     "No camera" : "Nėra kameros",
+    "Disable video (V)" : "Išjungti vaizdą (V)",
+    "Enable video (V)" : "Įjungti vaizdą (V)",
     "Disable video" : "Išjungti vaizdą",
     "Enable video" : "Įjungti vaizdą",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
@@ -450,6 +469,7 @@ OC.L10N.register(
     "Mute" : "Nutildyti",
     "Favorite" : "Mėgstamas",
     "Conversation settings" : "Pokalbio nustatymai",
+    "Description" : "Aprašas",
     "Chat notifications" : "Pokalbio pranešimai",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
@@ -462,6 +482,8 @@ OC.L10N.register(
     "Start time (optional)" : "Pradžios laikas (nebūtinas)",
     "Save" : "Įrašyti",
     "Edit" : "Taisyti",
+    "More information" : "Daugiau informacijos",
+    "Delete" : "Ištrinti",
     "Nextcloud URL" : "Nextcloud URL",
     "Nextcloud user" : "Nextcloud naudotojas",
     "User password" : "Naudotojo slaptažodis",
@@ -469,6 +491,7 @@ OC.L10N.register(
     "Matrix channel" : "Matrix kanalas",
     "Channel name" : "Kanalo pavadinimas",
     "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
+    "User name or email address" : "Naudotojo vardas ar el. pašto adresas",
     "Password" : "Slaptažodis",
     "Rocket.Chat channel" : "Rocket.Chat kanalas",
     "API token" : "API prieigos raktas",
@@ -486,6 +509,7 @@ OC.L10N.register(
     "MUC server URL" : "MUC serverio URL",
     "Jabber ID" : "Jabber ID",
     "unknown state" : "nežinoma būsena",
+    "Mark as read" : "Žymėti kaip skaitytą",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
     "You: {lastMessage}" : "Jūs: {lastMessage}",
@@ -494,6 +518,7 @@ OC.L10N.register(
     "No search results" : "Nėra paieškos rezultatų",
     "Groups" : "Grupės",
     "Circles" : "Ratai",
+    "Talk settings" : "Pokalbių nustatymai",
     "Users, groups and circles" : "Naudotojai, grupės ir ratai",
     "Users and groups" : "Naudotojai ir grupės",
     "Users and circles" : "Naudotojai ir ratai",
@@ -522,14 +547,19 @@ OC.L10N.register(
     "Microphone" : "Mikrofonas",
     "Camera" : "Kamera",
     "No microphone available" : "Nėra prieinamo mikrofono",
+    "Select microphone" : "Pasirinkti mikrofoną",
     "No camera available" : "Nėra prieinamos kameros",
+    "Select camera" : "Pasirinkti kamerą",
     "Reply" : "Atsakyti",
+    "Mark as unread" : "Žymėti kaip neskaitytą",
     "Go to file" : "Pereiti į failą",
     "[Unknown username]" : "[Nežinomas naudotojo vardas]",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
     "Share from Files" : "Bendrinti iš Failų",
+    "Add emoji" : "Pridėti šypsenėlę",
     "Send message" : "Siųsti žinutę",
     "File to share" : "Failas, kurį bendrinti",
     "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
@@ -551,15 +581,21 @@ OC.L10N.register(
     "Participants" : "Dalyviai",
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
+    "Details" : "Išsamiau",
     "Display name: " : "Rodomas vardas: ",
     "Choose devices" : "Pasirinkti įrenginius",
     "Attachments folder" : "Priedų aplankas",
+    "Privacy" : "Privatumas",
+    "Sounds" : "Garsai",
     "Keyboard shortcuts" : "Klavišų kombinacijos",
     "Search" : "Ieškoti",
+    "Space bar" : "Tarpas",
     "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Start call" : "Pradėti skambutį",
     "Toggle fullscreen" : "Perjungti visą ekraną",
     "Rename conversation" : "Pervadinti pokalbį",
+    "Exit fullscreen (F)" : "Išeiti iš viso ekrano (F)",
+    "Fullscreen (F)" : "Visas ekranas (F)",
     "Grid view" : "Tinklelio rodinys",
     "Send" : "Siųsti",
     "Add more files" : "Pridėti daugiau failų",
@@ -643,6 +679,9 @@ OC.L10N.register(
     "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
     "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
     "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
-    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“."
+    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
+    "Lower hand" : "Nuleisti ranką",
+    "Raise hand" : "Pakelti ranką",
+    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
