@@ -722,6 +722,7 @@ OC.L10N.register(
     "End recording and send" : "Acabar àudio e enviar",
     "Dismiss recording" : "Anullar l’enregistrament",
     "Access to the microphone was denied" : "L’accès al microfòn es estat refusat",
+    "Microphone either not available or disabled in settings" : "Microfòn siá indisponible o desactivat dins los paramètres",
     "Error while recording audio" : "Error en enregistrant l’àudio",
     "Talk recording from {time} ({conversation})" : "Enregistrament Talk a partir de {time} ({conversation})",
     "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
@@ -854,6 +855,7 @@ OC.L10N.register(
     "New in Talk 8" : "Nòu dins Talk 8",
     "New in Talk 9" : "Nòu dins Talk 9",
     "New in Talk 10" : "Nòu dins Talk 10",
+    "You removed the Matterbridge configuration." : "Avètz tirada la configuracion de Matterbridge.",
     "{user} wants to talk with you" : "{user} vòl vos parlar",
     "E-mail of the user" : "E-mail de l’utilizaire",
     "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
@@ -884,6 +886,9 @@ OC.L10N.register(
     "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
     "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
     "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
+    "{actor} started Matterbridge." : "{actor} lancèt Matterbridge.",
+    "You started Matterbridge." : "Avètz lançat Matterbridge.",
+    "{actor} stopped Matterbridge." : "{actor} arrestèt Matterbridge.",
     "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
     "Lower hand" : "Baissar la man",
     "Raise hand" : "Levar la man",
