@@ -171,7 +171,6 @@ class Manager {
 		return new Room(
 			$this,
 			$this->db,
-			$this->secureRandom,
 			$this->dispatcher,
 			$this->timeFactory,
 			$this->hasher,
@@ -299,26 +298,42 @@ class Manager {
 
 	/**
 	 * @param string $userId
+	 * @param array $sessionIds A list of talk sessions to consider for loading (otherwise no session is loaded)
 	 * @param bool $includeLastMessage
 	 * @return Room[]
 	 */
-	public function getRoomsForUser(string $userId, bool $includeLastMessage = false): array {
+	public function getRoomsForUser(string $userId, array $sessionIds = [], bool $includeLastMessage = false): array {
+		return $this->getRoomsForActor(Attendee::ACTOR_USERS, $userId, $sessionIds, $includeLastMessage);
+	}
+
+	/**
+	 * @param string $actorType
+	 * @param string $actorId
+	 * @param array $sessionIds A list of talk sessions to consider for loading (otherwise no session is loaded)
+	 * @param bool $includeLastMessage
+	 * @return Room[]
+	 */
+	public function getRoomsForActor(string $actorType, string $actorId, array $sessionIds = [], bool $includeLastMessage = false): array {
 		$query = $this->db->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectRoomsTable($query);
 		$helper->selectAttendeesTable($query);
-		$helper->selectSessionsTable($query);
 		$query->from('talk_rooms', 'r')
 			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
-				$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
-				$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
+				$query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)),
+				$query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)),
 				$query->expr()->eq('a.room_id', 'r.id')
 			))
-			->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
-				$query->expr()->eq('a.id', 's.attendee_id')
-			))
 			->where($query->expr()->isNotNull('a.id'));
 
+		if (!empty($sessionIds)) {
+			$helper->selectSessionsTable($query);
+			$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+				$query->expr()->eq('a.id', 's.attendee_id'),
+				$query->expr()->in('s.session_id', $query->createNamedParameter($sessionIds, IQueryBuilder::PARAM_STR_ARRAY))
+			));
+		}
+
 		if ($includeLastMessage) {
 			$this->loadLastMessageInfo($query);
 		}
@@ -332,7 +347,7 @@ class Manager {
 			}
 
 			$room = $this->createRoomObject($row);
-			if ($userId !== null && isset($row['actor_id'])) {
+			if ($actorType === Attendee::ACTOR_USERS && isset($row['actor_id'])) {
 				$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
 			}
 			$rooms[] = $room;
@@ -419,9 +434,6 @@ class Manager {
 				$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
 				$query->expr()->eq('a.room_id', 'r.id')
 			))
-			->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
-				$query->expr()->eq('a.id', 's.attendee_id')
-			))
 			->where($query->expr()->isNull('a.id'))
 			->andWhere($query->expr()->in('r.type', $query->createNamedParameter($allowedRoomTypes, IQueryBuilder::PARAM_INT_ARRAY)))
 			->andWhere($query->expr()->in('r.listable', $query->createNamedParameter($allowedListedTypes, IQueryBuilder::PARAM_INT_ARRAY)));
@@ -463,15 +475,11 @@ class Manager {
 		if ($userId !== null) {
 			// Non guest user
 			$helper->selectAttendeesTable($query);
-			$helper->selectSessionsTable($query);
 			$query->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 					$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
 					$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
 					$query->expr()->eq('a.room_id', 'r.id')
 				))
-				->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
-					$query->expr()->eq('a.id', 's.attendee_id')
-				))
 				->andWhere($query->expr()->isNotNull('a.id'));
 		}
 
@@ -511,12 +519,13 @@ class Manager {
 	 *
 	 * @param string $token
 	 * @param string|null $userId
+	 * @param string|null $sessionId
 	 * @param bool $includeLastMessage
 	 * @param bool $isSIPBridgeRequest
 	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
-	public function getRoomForUserByToken(string $token, ?string $userId, bool $includeLastMessage = false, bool $isSIPBridgeRequest = false): Room {
+	public function getRoomForUserByToken(string $token, ?string $userId, ?string $sessionId = null, bool $includeLastMessage = false, bool $isSIPBridgeRequest = false): Room {
 		$query = $this->db->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectRoomsTable($query);
@@ -527,15 +536,18 @@ class Manager {
 		if ($userId !== null) {
 			// Non guest user
 			$helper->selectAttendeesTable($query);
-			$helper->selectSessionsTable($query);
 			$query->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 					$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
 					$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
 					$query->expr()->eq('a.room_id', 'r.id')
-				))
-				->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+				));
+			if ($sessionId !== null) {
+				$helper->selectSessionsTable($query);
+				$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+					$query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)),
 					$query->expr()->eq('a.id', 's.attendee_id')
 				));
+			}
 		}
 
 		if ($includeLastMessage) {
@@ -612,26 +624,31 @@ class Manager {
 	 * @param string $token
 	 * @param string $actorType
 	 * @param string $actorId
+	 * @param string|null $sessionId
 	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
-	public function getRoomByActor(string $token, string $actorType, string $actorId): Room {
+	public function getRoomByActor(string $token, string $actorType, string $actorId, ?string $sessionId = null): Room {
 		$query = $this->db->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectRoomsTable($query);
 		$helper->selectAttendeesTable($query);
-		$helper->selectSessionsTable($query);
 		$query->from('talk_rooms', 'r')
 			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
 				$query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)),
 				$query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)),
 				$query->expr()->eq('a.room_id', 'r.id')
 			))
-			->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
-				$query->expr()->eq('a.id', 's.attendee_id')
-			))
 			->where($query->expr()->eq('r.token', $query->createNamedParameter($token)));
 
+		if ($sessionId !== null) {
+			$helper->selectSessionsTable($query);
+			$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+				$query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)),
+				$query->expr()->eq('a.id', 's.attendee_id')
+			));
+		}
+
 		$result = $query->execute();
 		$row = $result->fetch();
 		$result->closeCursor();
@@ -830,9 +847,11 @@ class Manager {
 			$room->setReadOnly(Room::READ_ONLY);
 			$room->setListable(Room::LISTABLE_NONE);
 
+			$user = $this->userManager->get($userId);
 			$this->participantService->addUsers($room,[[
 				'actorType' => Attendee::ACTOR_USERS,
 				'actorId' => $userId,
+				'displayName' => $user ? $user->getDisplayName() : $userId,
 			]]);
 			return $room;
 		}
@@ -840,11 +859,13 @@ class Manager {
 		$room = $this->createRoomObject($row);
 
 		try {
-			$room->getParticipant($userId);
+			$room->getParticipant($userId, false);
 		} catch (ParticipantNotFoundException $e) {
+			$user = $this->userManager->get($userId);
 			$this->participantService->addUsers($room,[[
 				'actorType' => Attendee::ACTOR_USERS,
 				'actorId' => $userId,
+				'displayName' => $user ? $user->getDisplayName() : $userId,
 			]]);
 		}
 
@@ -941,7 +962,7 @@ class Manager {
 					$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
 					$room->getParticipantBySession($sessionId);
 				} else {
-					$room->getParticipant($userId);
+					$room->getParticipant($userId, false);
 				}
 			} catch (ParticipantNotFoundException $e) {
 				// Do not leak the name of rooms the user is not a part of
